// src/AuthContext.ts
import React from "react";
var AuthContext = React.createContext(void 0);
AuthContext.displayName = "AuthContext";

// src/AuthProvider.tsx
import React2 from "react";
import { UserManager } from "oidc-client-ts";

// src/AuthState.ts
var initialAuthState = {
  isLoading: true,
  isAuthenticated: false
};

// src/reducer.ts
var reducer = (state, action) => {
  switch (action.type) {
    case "INITIALISED":
    case "USER_LOADED":
      return {
        ...state,
        user: action.user,
        isLoading: false,
        isAuthenticated: action.user ? !action.user.expired : false,
        error: void 0
      };
    case "USER_UNLOADED":
      return {
        ...state,
        user: void 0,
        isAuthenticated: false
      };
    case "ERROR":
      return {
        ...state,
        isLoading: false,
        error: action.error
      };
    default:
      return {
        ...state,
        isLoading: false,
        error: new Error(`unknown type ${action["type"]}`)
      };
  }
};

// src/utils.ts
var hasAuthParams = (location = window.location) => {
  let searchParams = new URLSearchParams(location.search);
  if ((searchParams.get("code") || searchParams.get("error")) && searchParams.get("state")) {
    return true;
  }
  searchParams = new URLSearchParams(location.hash.replace("#", "?"));
  if ((searchParams.get("code") || searchParams.get("error")) && searchParams.get("state")) {
    return true;
  }
  return false;
};
var normalizeErrorFn = (fallbackMessage) => (error) => {
  if (error instanceof Error) {
    return error;
  }
  return new Error(fallbackMessage);
};
var loginError = normalizeErrorFn("Login failed");

// src/AuthProvider.tsx
var userManagerContextKeys = [
  "clearStaleState",
  "signinPopup",
  "signinSilent",
  "signinRedirect",
  "querySessionStatus",
  "revokeAccessToken",
  "startSilentRenew",
  "stopSilentRenew"
];
var unsupportedEnvironment = (fnName) => () => {
  throw new Error(`UserManager#${fnName} was called from an unsupported context. If this is a server-rendered page, defer this call with useEffect() or pass a custom UserManager implementation.`);
};
var defaultUserManagerImpl = typeof window === "undefined" ? null : UserManager;
var AuthProvider = (props) => {
  const {
    children,
    onSigninCallback,
    skipSigninCallback,
    onRemoveUser,
    onSignoutRedirect,
    onSignoutPopup,
    implementation: UserManagerImpl = defaultUserManagerImpl,
    ...userManagerProps
  } = props;
  const [userManager] = React2.useState(() => UserManagerImpl && new UserManagerImpl(userManagerProps));
  const [state, dispatch] = React2.useReducer(reducer, initialAuthState);
  const userManagerContext = React2.useMemo(() => {
    var _a;
    return {
      settings: (_a = userManager == null ? void 0 : userManager.settings) != null ? _a : { ...userManagerProps },
      ...Object.fromEntries(userManagerContextKeys.map((key) => [
        key,
        userManager ? userManager[key].bind(userManager) : unsupportedEnvironment(key)
      ]))
    };
  }, [userManager]);
  React2.useEffect(() => {
    if (!userManager)
      return;
    void (async () => {
      try {
        if (hasAuthParams() && !skipSigninCallback) {
          const user2 = await userManager.signinCallback();
          onSigninCallback && onSigninCallback(user2);
        }
        const user = await userManager.getUser();
        dispatch({ type: "INITIALISED", user });
      } catch (error) {
        dispatch({ type: "ERROR", error: loginError(error) });
      }
    })();
  }, [userManager, skipSigninCallback, onSigninCallback]);
  React2.useEffect(() => {
    if (!userManager)
      return void 0;
    const handleUserLoaded = (user) => {
      dispatch({ type: "USER_LOADED", user });
    };
    userManager.events.addUserLoaded(handleUserLoaded);
    const handleUserUnloaded = () => {
      dispatch({ type: "USER_UNLOADED" });
    };
    userManager.events.addUserUnloaded(handleUserUnloaded);
    const handleSilentRenewError = (error) => {
      dispatch({ type: "ERROR", error });
    };
    userManager.events.addSilentRenewError(handleSilentRenewError);
    return () => {
      userManager.events.removeUserLoaded(handleUserLoaded);
      userManager.events.removeUserUnloaded(handleUserUnloaded);
      userManager.events.removeSilentRenewError(handleSilentRenewError);
    };
  }, [userManager]);
  const removeUser = React2.useMemo(() => userManager ? () => userManager.removeUser().then(onRemoveUser) : unsupportedEnvironment("removeUser"), [userManager, onRemoveUser]);
  const signoutRedirect = React2.useMemo(() => userManager ? (args) => userManager.signoutRedirect(args).then(onSignoutRedirect) : unsupportedEnvironment("signoutRedirect"), [userManager, onSignoutRedirect]);
  const signoutPopup = React2.useMemo(() => userManager ? (args) => userManager.signoutPopup(args).then(onSignoutPopup) : unsupportedEnvironment("signoutPopup"), [userManager, onSignoutPopup]);
  return /* @__PURE__ */ React2.createElement(AuthContext.Provider, {
    value: {
      ...state,
      ...userManagerContext,
      removeUser,
      signoutRedirect,
      signoutPopup
    }
  }, children);
};

// src/useAuth.ts
import React3 from "react";
var useAuth = () => {
  const context = React3.useContext(AuthContext);
  if (!context) {
    throw new Error("AuthProvider context is undefined, please verify you are calling useAuth() as child of a <AuthProvider> component.");
  }
  return context;
};

// src/withAuth.tsx
import React4 from "react";
function withAuth(Component) {
  const displayName = `withAuth(${Component.displayName || Component.name})`;
  const C = (props) => {
    const auth = useAuth();
    return /* @__PURE__ */ React4.createElement(Component, {
      ...props,
      ...auth
    });
  };
  C.displayName = displayName;
  return C;
}
export {
  AuthContext,
  AuthProvider,
  hasAuthParams,
  useAuth,
  withAuth
};
//# sourceMappingURL=react-oidc-context.esm.js.map
